@@ -1,5 +1,5 @@
 package Date::Manip::Lang::german;
-# Copyright (c) 1998-2013 Sullivan Beck. All rights reserved.
+# Copyright (c) 1998-2014 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -13,15 +13,14 @@ use warnings;
 use utf8;
 
 our($VERSION);
-$VERSION='6.42';
+$VERSION='6.46';
 
 our($Language,@Encodings,$LangName,$YearAdded);
 @Encodings = qw(utf-8 iso-8859-1 perl);
 $LangName  = "German";
 $YearAdded = 1998;
 
-# These strings are raw undecoded UTF-8 octets:
-{ no utf8; $Language = {
+$Language = {
   ampm => [['FM', 'vorm.'], ['EM', 'nachm.']],
   at => ['um'],
   day_abb => [
@@ -255,6 +254,6 @@ $YearAdded = 1998;
   on => ['am'],
   times => { mittag => '12:00:00', mitternacht => '00:00:00' },
   when => [['vor', 'vorigen', 'vorherigen', 'vorherige'], ['in', 'spater', 'später']],
-}}
+};
 
 1;
